package LATMOS::Accounts::Web::Controller::Json::Tree;
use Moose;
use namespace::autoclean;

BEGIN { extends 'Catalyst::Controller'; }

=head1 NAME

LATMOS::Accounts::Web::Controller::Json::Expire - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head2 index

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;

    my $base = $c->model('Accounts')->db;

    my %users = map { $_ => 1 } $base->search_objects('user', 'active=1', 'givenName=*');
    my %dpmts = map { $_ => 1 } $base->search_objects('group', 'sutype=dpmt');
    my %userdpmt = $base->attributes_summary_by_object('user', 'department');
    my %dpmtmanager = $base->attributes_summary_by_object('group', 'managedBy');
    my %usermanager = $base->attributes_summary_by_object('user', 'managerContact');

    my %nodes;
    my $data = {
        nodes => [],
        links => [],
    };

    foreach my $user (keys %users) {
        push(@{ $data->{nodes} }, {
                "name" => $user,
                label => $user,
        });
        $nodes{$user} = $#{ $data->{nodes} };
    }
    push(@{ $data->{nodes} }, {
            "name" => '-direction',
            label => 'Direction',
        });
    $nodes{'-direction'} = $#{ $data->{nodes} };

    foreach my $user (keys %dpmts) {
        push(@{ $data->{nodes} }, {
                "name" => '-' . $user,
                label => $user,
        });
        $nodes{'-' . $user} = $#{ $data->{nodes} };
        push(@{ $data->{links} },
            {
                "source" => $nodes{'-' . $user},
                "target" => $nodes{'-direction'},
                color => 'red',
            }
        );

    }

    
    foreach my $user (keys %users) {

        if (my $dpmt = $userdpmt{$user}) {
            push(@{ $data->{links} },
                {
                    "source" => $nodes{$user},
                    "target" => $nodes{'-' . $dpmt->[0]},
                }
            ) if ($dpmt->[0]);
        }
        if (my $manag = $usermanager{$user}) {
            my $target = $manag->[0];
            push(@{ $data->{links} },
                {
                    "source" => $nodes{$user},
                    "target" => $nodes{$target},
                }
            ) if ($target);
        }


    }
    
    $c->stash->{data} = $data;
}



=encoding utf8

=head1 AUTHOR

Olivier Thauvin,Guyancourt - B1428,+33 1 80285052,

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
